==> piwigo-2.5.3.zip: piwigo/language/mn_MN/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2013 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['It appears your webhost is currently running PHP %s.'] = 'Таны вэбсервер PHP %s хувилбарыг ашиглаж байна';
$lang['Piwigo was not able to configure PHP 5.'] = 'Piwigo PHP 5-г тохиргоог өөрчилж чадсангүй';
$lang['Congratulations, Piwigo installation is completed'] = 'Танд баяр хүргэе, Piwigo амжилттай сууж дууслаа.';
$lang['Connection to server succeed, but it was impossible to connect to database'] = 'Сервертэй амжилттай холбогдсон боловч мэдээллийн сантай холбогдох боломж алга байна.';
$lang['Try to configure PHP 5'] = 'PHP 5 тохиргоогоо өөрчилж үзнэ үү';
$lang['User'] = 'Хэрэглэгч';
$lang['Just another Piwigo gallery'] = 'Бас нэг Piwigo-н галарей ';
$lang['Database configuration'] = 'Мэдээллийн сангийн тохиргоо';
$lang['Welcome to my photo gallery'] = 'Миний зургийн цомогт тавтай морилно уу';
$lang['please enter your password again'] = 'нууц үгээ дахин оруулна уу';
$lang['Start Install'] = 'Суулгаж эхлэх';
$lang['Sorry!'] = 'Уучлаарай';
$lang['Password ']['confirm'] = 'Нууц үгээ давтах';
$lang['Can\'t connect to server'] = 'Сервертэй холбогдож чадахгүй байна';
$lang['Database name'] = 'Мэдээллийн сангын нэр';
$lang['Default gallery language'] = 'Үндсэн хэл';
$lang['PHP 5 is required'] = 'PHP 5 шаардлагатай';
$lang['Download the config file'] = 'Тохиргооны файлыг татах';
$lang['Admin configuration'] = 'Админий тохиргоо';
$lang['Basic configuration'] = 'Үндсэн тохиргоо';
$lang['webmaster login can\'t contain characters \' or "'] = 'Вэбмастерийн нэрэнд \' or " гэсэн тэмдэгт орох ёсгүй.';
$lang['verification'] = 'баталгаажуулалт';
$lang['Visitors will be able to contact site administrator with this mail'] = 'Хэрэглэгчид энэ имэйл хаягаар админтай холбогдох боломжтой';
$lang['Hope to see you back soon.'] = 'Тантай удахгүй эргэн уулзана гэдэгт найдаж байна.';
$lang['Welcome to your new installation of Piwigo!'] = 'Piwigo-г шинээр суулгах хэсэгт тавтай морилно уу!';
$lang['enter a login for webmaster'] = 'Вэбмастерийн мэдээллээ оруулна уу';
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = 'Тусламж хэрэгтэй бол <a href="%s">Piwigo message board</a> хаягаар хандаж асуултаа асуугаарай.';
$lang['Creation of config file local/config/database.inc.php failed.'] = 'Тохиргооны файл local/config/database.inc.php-г үүсгэж чадсангүй';
?>

==> piwigo-2.7.4.zip: piwigo/language/mn_MN/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2014 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['It appears your webhost is currently running PHP %s.'] = 'Таны вэбсервер PHP %s хувилбарыг ашиглаж байна';
$lang['Piwigo was not able to configure PHP 5.'] = 'Piwigo PHP 5-г тохиргоог өөрчилж чадсангүй';
$lang['Congratulations, Piwigo installation is completed'] = 'Танд баяр хүргэе, Piwigo амжилттай сууж дууслаа.';
$lang['Connection to server succeed, but it was impossible to connect to database'] = 'Сервертэй амжилттай холбогдсон боловч мэдээллийн сантай холбогдох үед алдаа гарлаа.';
$lang['Try to configure PHP 5'] = 'PHP 5 тохиргоогоо өөрчилж үзнэ үү';
$lang['User'] = 'Хэрэглэгч';
$lang['Just another Piwigo gallery'] = 'Piwigo-н галерей нэгээр нэмэгдлээ';
$lang['Database configuration'] = 'Мэдээллийн сангийн тохиргоо';
$lang['Welcome to my photo gallery'] = 'Миний зургийн цомогт тавтай морилно уу';
$lang['please enter your password again'] = 'нууц үгээ дахин оруулна уу';
$lang['Start Install'] = 'Суулгаж эхлэх';
$lang['Sorry!'] = 'Уучлаарай';
$lang['Password ']['confirm'] = 'Нууц үгээ давтах';
$lang['Can\'t connect to server'] = 'Сервертэй холбогдож чадахгүй байна';
$lang['Database name'] = 'Мэдээллийн сангын нэр';
$lang['Default gallery language'] = 'Үндсэн хэл';
$lang['PHP 5 is required'] = 'PHP 5 шаардлагатай';
$lang['Download the config file'] = 'Тохиргооны файлыг татах';
$lang['Admin configuration'] = 'Админий тохиргоо';
$lang['Basic configuration'] = 'Үндсэн тохиргоо';
$lang['webmaster login can\'t contain characters \' or "'] = 'Вэбмастерийн нэрэнд \' or " гэсэн тэмдэгт орох ёсгүй.';
$lang['verification'] = 'баталгаажуулалт';
$lang['Visitors will be able to contact site administrator with this mail'] = 'Хэрэглэгчид энэ имэйл хаягаар админтай холбогдох боломжтой';
$lang['Hope to see you back soon.'] = 'Тантай удахгүй эргэн уулзана гэдэгт найдаж байна.';
$lang['Welcome to your new installation of Piwigo!'] = 'Piwigo-г шинээр суулгах хэсэгт тавтай морилно уу!';
$lang['enter a login for webmaster'] = 'Вэбмастерийн мэдээллээ оруулна уу';
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = 'Тусламж хэрэгтэй бол <a href="%s">Piwigo message board</a> хаягаар хандаж асуултаа асуугаарай.';
$lang['Creation of config file local/config/database.inc.php failed.'] = 'Тохиргооны файл local/config/database.inc.php-г үүсгэж чадсангүй';
$lang['Keep it confidential, it enables you to access administration panel'] = 'Удирдлагын талбарт хандах эрхийг нээх тул энэ мэдээллийг нууцлан хадгална уу';
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = 'Мэдээллийн сангийн талбаруудад энэ утгыг угтвар хэсэг болгон ашиглах болно. Ингэснээр талбаруудыг удирдаж зохицуулахад илүү хялбар болдог.';
$lang['localhost or other, supplied by your host provider'] = 'localhost эсвэл веб байршуулж буй компаниас өгсөн нэр';
$lang['user login given by your host provider'] = 'веб байршуулж буй компаниас өгсөн хэрэглэгчийн нэр';
$lang['user password given by your host provider'] = 'веб байршуулж буй компаниас өгсөн нууц үг';
$lang['Database table prefix'] = 'Мэдээллийн сангийн талбарийн угтвар утга';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = 'Тохиргооны файлыг татан авч өөрчлөөд local/config хавтас уруу буцаан хуулаах боломжтой.';
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = 'Тохиргоогоо өөрөө өөрчлөөд Piwigo-г дахин ачаалж болно гэдгийг санаарай.';
$lang['Don\'t hesitate to consult our forums for any help : %s'] = 'Тусламж хэрэгтэй бол манай онлайн форумд хандаарай: %s';
$lang['Host'] = 'Байршуулах компьютер';
$lang['Installation'] = 'Суулгац';
?>
